package main

import (
	"fmt"
	"log"

	"git.paulbsd.com/paulbsd/coronafana/src/config"
	"git.paulbsd.com/paulbsd/coronafana/src/coronafana"
	_ "github.com/go-sql-driver/mysql"
	"xorm.io/xorm"
	"xorm.io/xorm/names"
)

func main() {
	var cfg config.Config
	var cr coronafana.Coronafana
	var err error

	err = cfg.GetConfig()
	if err != nil {
		log.Fatalln(err)
	}

	db, err := xorm.NewEngine("mysql",
		fmt.Sprintf("%s:%s@tcp(%s)/%s",
			cfg.DbUsername,
			cfg.DbPassword,
			cfg.DbHostname,
			cfg.DbName))
	if err != nil {
		log.Fatalln(err)
	}
	defer db.Close()

	db.SetMapper(names.GonicMapper{})
	db.ShowSQL(cfg.Debug)

	for object := range []interface{}{new(coronafana.Coronaglobaldata), new(coronafana.Coronapaysdata)} {
		err = db.Sync2(object)
	}

	cr, err = coronafana.GetData(cfg)
	if err != nil {
		log.Fatalln(err)
	}

	// Process data
	err = cr.InsertData(cfg, *db)
	if err != nil {
		log.Fatalln(err)
	}
}
